<?php

namespace Litecms\BoardSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\BoardSetting\Http\Requests\BoardSettingRequest;
use Litecms\BoardSetting\Interfaces\BoardSettingRepositoryInterface;
use Litecms\BoardSetting\Models\BoardSetting;

/**
 * Resource controller class for board_setting.
 */
class BoardSettingResourceController extends BaseController
{

    /**
     * Initialize board_setting resource controller.
     *
     * @param type BoardSettingRepositoryInterface $board_setting
     *
     * @return null
     */
    public function __construct(BoardSettingRepositoryInterface $board_setting)
    {
        parent::__construct();
        $this->repository = $board_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\BoardSetting\Repositories\Criteria\BoardSettingResourceCriteria::class);
    }

    /**
     * Display a list of board_setting.
     *
     * @return Response
     */
    public function index(BoardSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\BoardSetting\Repositories\Presenter\BoardSettingPresenter::class)
                ->$function();
        }

        $board_settings = $this->repository->paginate();

        return $this->response->title(trans('board_setting::board_setting.names'))
            ->view('board_setting::board_setting.index', true)
            ->data(compact('board_settings'))
            ->output();
    }

    /**
     * Display board_setting.
     *
     * @param Request $request
     * @param Model   $board_setting
     *
     * @return Response
     */
    public function show(BoardSettingRequest $request, BoardSetting $board_setting)
    {

        if ($board_setting->exists) {
            $view = 'board_setting::board_setting.show';
        } else {
            $view = 'board_setting::board_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('board_setting::board_setting.name'))
            ->data(compact('board_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new board_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BoardSettingRequest $request)
    {

        $board_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('board_setting::board_setting.name')) 
            ->view('board_setting::board_setting.create', true) 
            ->data(compact('board_setting'))
            ->output();
    }

    /**
     * Create new board_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BoardSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $board_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('board_setting::board_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('board_setting/board_setting/' . $board_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/board_setting/board_setting'))
                ->redirect();
        }

    }

    /**
     * Show board_setting for editing.
     *
     * @param Request $request
     * @param Model   $board_setting
     *
     * @return Response
     */
    public function edit(BoardSettingRequest $request, BoardSetting $board_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('board_setting::board_setting.name'))
            ->view('board_setting::board_setting.edit', true)
            ->data(compact('board_setting'))
            ->output();
    }

    /**
     * Update the board_setting.
     *
     * @param Request $request
     * @param Model   $board_setting
     *
     * @return Response
     */
    public function update(BoardSettingRequest $request, BoardSetting $board_setting)
    {
        try {
            $attributes = $request->all();

            $board_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('board_setting::board_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('board_setting/board_setting/' . $board_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('board_setting/board_setting/' . $board_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the board_setting.
     *
     * @param Model   $board_setting
     *
     * @return Response
     */
    public function destroy(BoardSettingRequest $request, BoardSetting $board_setting)
    {
        try {

            $board_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('board_setting::board_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('board_setting/board_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('board_setting/board_setting/' . $board_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple board_setting.
     *
     * @param Model   $board_setting
     *
     * @return Response
     */
    public function delete(BoardSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('board_setting::board_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('board_setting/board_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/board_setting/board_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted board_settings.
     *
     * @param Model   $board_setting
     *
     * @return Response
     */
    public function restore(BoardSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('board_setting::board_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/board_setting/board_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/board_setting/board_setting/'))
                ->redirect();
        }

    }

}
